@@ -24,7 +24,8 @@ role_cache = TTLCache(maxsize=10, ttl=3600)
 
 class Client(BaseClient):
     boto3_client = None
-    grantless_scope = ''
+    grantless_scope: str = ''
+    keep_restricted_data_token: bool = False
 
     def __init__(
             self,
@@ -109,7 +110,7 @@ class Client(BaseClient):
                         )
 
     def _request(self, path: str, *, data: dict = None, params: dict = None, headers=None,
-                 add_marketplace=True) -> ApiResponse:
+                 add_marketplace=True, res_no_data: bool = False) -> ApiResponse:
         if params is None:
             params = {}
         if data is None:
@@ -126,10 +127,10 @@ class Client(BaseClient):
                       headers=headers or self.headers,
                       auth=self._sign_request(),
                       proxies=self.proxies)
-        return self._check_response(res)
+        return self._check_response(res, res_no_data)
 
-    def _check_response(self, res) -> ApiResponse:
-        if self.method == 'DELETE' and 200 <= res.status_code < 300:
+    def _check_response(self, res, res_no_data: bool = False) -> ApiResponse:
+        if (self.method == 'DELETE' or res_no_data) and 200 <= res.status_code < 300:
             try:
                 js = res.json() or {}
             except JSONDecodeError:
@@ -166,3 +167,11 @@ class Client(BaseClient):
         }
 
         return self._request(path, data=data, params=params, headers=headers)
+
+    def __enter__(self):
+        self.keep_restricted_data_token = True
+        return self
+
+    def __exit__(self, *args, **kwargs):
+        self.restricted_data_token = None
+        self.keep_restricted_data_token = False
